@@ -122,6 +122,11 @@ parser.add_argument(
     action="store_true",
     help="Run in a loop to update display periodic.",
 )
+parser.add_argument(
+    "--timg",
+    action="store_true",
+    help="Pass output to timg for matplotlib backend, implies --as-raw-bytes.",
+)
 parser.add_argument(
     "-n",
     "--interval",
@@ -148,6 +153,13 @@ parser.add_argument(
     help="Keyword that the stat must not contain for it to be plotted, case sensitive.",
 )
 
+parser.add_argument(
+    "--terminal-width", type=int, help="Manually set the terminal width.",
+)
+parser.add_argument(
+    "--terminal-height", type=int, help="Manually set the terminal height.",
+)
+
 
 class EmptyEventFileError(Exception):
     pass
@@ -336,6 +348,8 @@ def run():
                 _args.axes_color = "black"
             if _args.ticks_color is None:
                 _args.ticks_color = "white"
+        if _args.timg:
+            _args.as_raw_bytes = True
         main(_args)
     except KeyboardInterrupt:
         pass
